/*
 * Copyright © 2020-2023 Fachhochschule für die Wirtschaft (FHDW) Hannover
 *
 * This file is part of gaming-core.
 *
 * Gaming-core is free software: you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free Software
 * Foundation, either version 3 of the License, or (at your option) any later
 * version.
 *
 * Gaming-core is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License along with
 * gaming-core. If not, see <http://www.gnu.org/licenses/>.
 */
package de.fhdw.gaming.core.domain.util;

/**
 * A variant of {@link java.util.function.Function} which may throw a checked exception.
 *
 * @param <T> Type of input.
 * @param <R> Type of output.
 * @param <E> Type of exception.
 */
public interface FunctionE<T, R, E extends Exception> {

    /**
     * Applies this function to the given argument.
     *
     * @param arg The input argument.
     * @return The result of the function application.
     */
    R apply(T arg) throws E;
}
