/*
 * Copyright © 2020 Fachhochschule für die Wirtschaft (FHDW) Hannover
 *
 * This file is part of gaming-core.
 *
 * Gaming-core is free software: you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free Software
 * Foundation, either version 3 of the License, or (at your option) any later
 * version.
 *
 * Gaming-core is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License along with
 * gaming-core. If not, see <http://www.gnu.org/licenses/>.
 */
package de.fhdw.gaming.core.domain.util;

import java.util.List;

import de.fhdw.gaming.core.domain.GameBuilder;
import de.fhdw.gaming.core.domain.GameBuilderFactory;
import de.fhdw.gaming.core.domain.GameException;
import de.fhdw.gaming.core.domain.Strategy;
import de.fhdw.gaming.core.ui.InputProvider;

/**
 * Wraps a {@link GameBuilderFactory} and supplies a suitable {@link Object#toString()} method.
 */
public final class GameBuilderFactoryWrapper implements GameBuilderFactory {

    /**
     * The wrapped game factory.
     */
    private final GameBuilderFactory wrappedFactory;

    /**
     * Creates a {@link GameBuilderFactoryWrapper}.
     *
     * @param wrappedFactory The wrapped game factory
     */
    public GameBuilderFactoryWrapper(final GameBuilderFactory wrappedFactory) {
        this.wrappedFactory = wrappedFactory;
    }

    @Override
    public String getName() {
        return this.wrappedFactory.getName();
    }

    @Override
    public int getMinimumNumberOfPlayers() {
        return this.wrappedFactory.getMinimumNumberOfPlayers();
    }

    @Override
    public int getMaximumNumberOfPlayers() {
        return this.wrappedFactory.getMaximumNumberOfPlayers();
    }

    @Override
    public List<? extends Strategy<?, ?, ?>> getStrategies() {
        return this.wrappedFactory.getStrategies();
    }

    @Override
    public GameBuilder createGameBuilder(final InputProvider inputProvider) throws GameException {
        return this.wrappedFactory.createGameBuilder(inputProvider);
    }

    @Override
    public String toString() {
        return this.getName();
    }
}
